import { Grid, GridCol } from "@treejs/components/Grid";
import Image from "next/image";
import { isEmpty, isNil, map } from "ramda";
import { FC, Fragment, useMemo } from "react";
import { projects } from "../constants/projects";
import MyTitle from "./MyTitle";

const FullStory: FC = () => {
	const projectsRender = useMemo(() => {
		let i = 0;
		return map((project) => {
			i++;
			return (
				<Fragment key={i}>
					<div className="border-timeline border-dotted border-l-4 pl-4 my-2">
						<p className="mb-2 font-bold">{project.name}</p>
						<p className="mb-2 font-thin">
							{project.dateFrom} - {project.dateTo}
						</p>
						<p>
							{project.desciption}
							{!isNil(project.link) ? (
								<>
									<a
										href={project.link}
										target="_blank"
										rel="noreferrer"
										className="ml-1"
									>
										Odkaz na projekt
									</a>
									.
								</>
							) : null}
						</p>
					</div>
					{i === projects.length ? null : (
						<svg height="20" width="20" className="-ml-2">
							<circle cx="10" cy="10" r="9" fill="#B25068" />
						</svg>
					)}
				</Fragment>
			);
		}, projects);
	}, []);

	return (
		<Grid cols={6} className="mt-28">
			<GridCol colSpan={1} className="text-center">
				<Image
					src="/story.svg"
					alt="story"
					width={200}
					height={200}
					objectFit="contain"
				/>
			</GridCol>
			<GridCol colSpan={5} className="ml-10">
				<MyTitle left="Na" right="Projektech" />
				<div className="mt-10">{projectsRender}</div>
			</GridCol>
		</Grid>
	);
};

export default FullStory;
